<p align="center">
<img src="https://github.com/crowdsecurity/misp-feed-generator/raw/main/docs/static/logo.png" alt="CrowdSec" title="CrowdSec" width="350" height="300" />
</p>
<p align="center">
<img src="https://img.shields.io/badge/build-pass-green">
<img src="https://img.shields.io/badge/tests-pass-green">
</p>
<p align="center">
&#x1F4DA; <a href="#installation/">Documentation</a>
&#x1F4A0; <a href="https://hub.crowdsec.net">Hub</a>
&#128172; <a href="https://discourse.crowdsec.net">Discourse </a>
</p>

# CrowdSec MISP Feed Generator

This bouncer generates MISP Feed from CrowdSec decisions. It exposes this Feed over HTTP/S.
This can be used to feed CrowdSec decisions to MISP using the "Feeds" functionality of MISP.

# Documentation

Please follow [the official documentation](https://docs.crowdsec.net/docs/next/bouncers/misp-feed-generator)
